@@ -20,6 +20,10 @@
 #' 
 #' @export CrossoverGUI
 CrossoverGUI <- function() {
+  if (!exists(".summary_table", envir=Crossover.env)) {
+    assign(".summary_table",  buildSummaryTable(), envir=Crossover.env)
+  }
+  
   if (!"jri.jar" %in% tolower(sapply(.jclassPath(), function(x) {substring(x, first=nchar(x)-6)}))) {
     warning(paste(c("JRI.jar seems to be missing from the classpath.",
                     "The graphical user interface will most likely not be available.",
